@@ -660,7 +660,7 @@ gcm_calibrate_argyll_display_generate_profile (GcmCalibrateArgyll *calibrate_arg
 	g_ptr_array_add (array, g_strdup_printf ("-D%s", description));
 	g_ptr_array_add (array, g_strdup_printf ("-C%s", copyright));
 	g_ptr_array_add (array, g_strdup (gcm_calibrate_argyll_get_quality_arg (calibrate_argyll)));
-	g_ptr_array_add (array, g_strdup ("-aS"));
+	g_ptr_array_add (array, g_strdup ("-aG"));
 	g_ptr_array_add (array, g_strdup (basename));
 	argv = gcm_utils_ptr_array_to_strv (array);
 	gcm_calibrate_argyll_debug_argv (command, argv);
@@ -1703,6 +1703,7 @@ gcm_calibrate_argyll_printer (GcmCalibrate *calibrate,
 		      "basename", &basename,
 		      "print-kind", &print_kind,
 		      NULL);
+	g_assert (print_kind != GCM_CALIBRATE_PRINT_KIND_UNKNOWN);
 	working_path = gcm_calibrate_get_working_path (GCM_CALIBRATE (calibrate_argyll));
 
 	/* print */
