@@ -109,6 +109,10 @@ gcm_picker_refresh_results (void)
 	GtkImage *image;
 	GtkLabel *label;
 
+	/* nothing set yet */
+	if (profile_filename == NULL)
+		goto out;
+
 	/* copy as we're modifying the value */
 	cd_color_copy_xyz (&last_sample, &color_xyz);
 
@@ -129,12 +133,18 @@ gcm_picker_refresh_results (void)
 	transform_rgb = cmsCreateTransform (profile_xyz, TYPE_XYZ_DBL,
 					    profile_rgb, TYPE_RGB_8,
 					    INTENT_PERCEPTUAL, 0);
+	if (transform_rgb == NULL)
+		goto out;
 	transform_lab = cmsCreateTransform (profile_xyz, TYPE_XYZ_DBL,
 					    profile_lab, TYPE_Lab_DBL,
 					    INTENT_PERCEPTUAL, 0);
+	if (transform_lab == NULL)
+		goto out;
 	transform_error = cmsCreateTransform (profile_rgb, TYPE_RGB_8,
 					      profile_xyz, TYPE_XYZ_DBL,
 					      INTENT_PERCEPTUAL, 0);
+	if (transform_error == NULL)
+		goto out;
 
 	cmsDoTransform (transform_rgb, &color_xyz, &color_rgb, 1);
 	cmsDoTransform (transform_lab, &color_xyz, &color_lab, 1);
@@ -217,7 +227,7 @@ gcm_picker_refresh_results (void)
 	/* set image */
 	image = GTK_IMAGE (gtk_builder_get_object (builder, "image_preview"));
 	gtk_image_set_from_pixbuf (image, pixbuf);
-
+out:
 	g_free (text_ambient);
 	g_free (text_error);
 	g_free (text_lab);
@@ -530,6 +540,7 @@ gcm_prefs_setup_space_combobox (GtkWidget *widget)
 	CdDevice *device_tmp;
 	CdProfile *profile;
 	const gchar *filename;
+	const gchar *tmp;
 	gboolean has_colorspace_description;
 	gboolean has_profile = FALSE;
 	gboolean has_vcgt;
@@ -586,8 +597,11 @@ gcm_prefs_setup_space_combobox (GtkWidget *widget)
 			gcm_prefs_combobox_add_profile (widget, profile, &iter);
 
 			/* set active option */
-			if (g_strcmp0 (filename, profile_filename) == 0)
+			tmp = cd_profile_get_metadata_item (profile, CD_PROFILE_METADATA_STANDARD_SPACE);
+			if (g_strcmp0 (tmp, "adobe-rgb") == 0) {
+				profile_filename = filename;
 				gtk_combo_box_set_active_iter (GTK_COMBO_BOX (widget), &iter);
+			}
 			has_profile = TRUE;
 		}
 	}
@@ -745,9 +759,6 @@ gcm_picker_startup_cb (GApplication *application, gpointer user_data)
 	/* disable some ui if no hardware */
 	gcm_picker_sensor_client_setup_ui ();
 
-	/* default to AdobeRGB */
-	profile_filename = "/usr/share/color/icc/Argyll/ClayRGB1998.icm";
-
 	/* setup RGB combobox */
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "combobox_colorspace"));
 	gcm_prefs_set_combo_simple_text (widget);
